;
var util = (function () {
    var storage = {
        enabled: !!window.localStorage,
        _namespacePrefix: '_androidbox_',
        _serialize: function (data) {
            return JSON.stringify(data);
        },
        _deserialize: function (data) {
            return JSON.parse(data)
        },
        get: function (key) {
            if (this.enabled) {
                return this._deserialize(localStorage.getItem(this._namespacePrefix + key));
            }
        },
        set: function (key, value) {
            if (this.enabled) {
                localStorage.setItem(this._namespacePrefix + key, this._serialize(value) || []);
            }
        },
        remove: function (key) {
            if (this.enabled) {
                localStorage.removeItem(this._namespacePrefix + key);
            }
        },
        clear: function () {
            if (this.enabled) {
                localStorage.clear();
            }
        }
    };

    var parseUrl = function (url) {
        var a = document.createElement('a');
        a.href = url;

        return {
            source: url,
            protocol: a.protocol.replace(':', ''),
            host: a.hostname,
            port: a.port,
            query: a.search,
            params: (function () {
                var ret = {};
                var segment = a.search.replace(/^\?/, '').split("&");
                var length = segment.length;
                var i = 0;
                var array;

                for (; i < length; i++) {
                    if (!segment[i]) continue;
                    array = segment[i].split('=');
                    ret[array[0]] = array[1];
                }
                return ret;
            })()
        };
    };

    var isEmpty = function (str) {
        return str.replace(/(^\s*)|(\s*$)/g, '').length === 0;
    }

    return {
        storage: storage,
        parseUrl: parseUrl,
        isEmpty: isEmpty
    };
})();